# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/fr_FR/__init__.py

job_formats_fr_fr <- c(
  "Accessoiriste",
  "Accompagnateur de moyenne montagne",
  "Accompagnateur de tourisme \u00e9questre",
  "Accompagnateur de voyages",
  "Acheteur",
  "Acheteur d\'espaces publicitaires",
  "Acousticien",
  "Actuaire",
  "Adjoint",
  "Administrateur de base de donn\u00e9es",
  "Administrateur de biens",
  "Administrateur de logiciels de laboratoire",
  "Administrateur de mission humanitaire",
  "Administrateur de r\u00e9seau",
  "Administrateur de spectacle",
  "Administrateur judiciaire",
  "Agenceur de cuisines et salles de bains",
  "Agent",
  "Agent artistique",
  "Agent d\'assurances",
  "Agent de d\u00e9veloppement des \u00e9nergies renouvelables",
  "Agent de d\u00e9veloppement local",
  "Agent de d\u00e9veloppement touristique",
  "Agent de la surveillance SNCF",
  "Agent de propret\u00e9 et d\'hygi\u00e8ne",
  "Agent de propret\u00e9 urbaine",
  "Agent de s\u00e9curit\u00e9",
  "Agent de service commercial train",
  "Agent des m\u00e9thodes",
  "Agent de transit",
  "Agriculteur",
  "Agronome",
  "Aide m\u00e9dico-psychologique",
  "Aide-soignant",
  "Ajusteur",
  "Ambulancier",
  "Analyste de cr\u00e9dit",
  "Analyste financier",
  "Anatomiste",
  "Anesth\u00e9siste-r\u00e9animateur",
  "Animalier de laboratoire",
  "Animateur",
  "Animateur 2D et 3D",
  "Animateur d\'activit\u00e9s physiques et sportives",
  "Animateur de bassin versant",
  "Animateur de radio et de t\u00e9l\u00e9vision",
  "Animateur du patrimoine",
  "Animateur nature",
  "Antiquaire",
  "Apiculteur",
  "Aquaculteur",
  "Arboriculteur",
  "Architecte",
  "Architecte d\'int\u00e9rieur",
  "Architecte naval",
  "Architecte produit industriel",
  "Architecte r\u00e9seau",
  "Architecte web",
  "Archiviste",
  "Arch\u00e9ologue",
  "A\u00e9rodynamicien",
  "Aromaticien",
  "Artiste de cirque",
  "Ascensoriste",
  "Assistant",
  "Assistant",
  "Assistant",
  "Assistant de gestion en PME",
  "Assistant dentaire",
  "Assistant de service social",
  "Assistant en ressources humaines",
  "Astrophysicien",
  "Attach\u00e9",
  "Attach\u00e9",
  "Attach\u00e9 d\'administration",
  "Attach\u00e9 de presse",
  "Attach\u00e9 de recherche clinique",
  "Audioproth\u00e9siste",
  "Auditeur externe",
  "Auditeur interne",
  "Auteur interpr\u00e8te",
  "Auxiliaire de pu\u00e9riculture",
  "Auxiliaire de vie sociale",
  "Auxiliaire sp\u00e9cialis\u00e9 v\u00e9t\u00e9rinaire",
  "Avocat",
  "Bact\u00e9riologiste",
  "Barman",
  "Batelier",
  "Biblioth\u00e9caire",
  "Bijoutier",
  "Bio-informaticien",
  "Biologiste en environnement",
  "Biologiste m\u00e9dical",
  "Biostatisticien",
  "\u00c9b\u00e9niste",
  "Botaniste",
  "Bottier",
  "Boucher",
  "Boulanger",
  "Brodeur",
  "Bronzier",
  "Cadreur",
  "Caissier",
  "Canalisateur",
  "Carreleur-mosa\u00efste",
  "Carrossier",
  "Cartographe",
  "Caviste",
  "Chanteur",
  "Charcutier",
  "Charg\u00e9",
  "Charg\u00e9 d\'affaires en g\u00e9nie climatique",
  "Charg\u00e9 d\'affaires en g\u00e9nie m\u00e9canique",
  "Charg\u00e9 de client\u00e8le banque",
  "Charg\u00e9 de communication interne",
  "Charg\u00e9 de pharmacovigilance",
  "Charg\u00e9 de production",
  "Charg\u00e9 de projet \u00e9v\u00e9nementiel",
  "Charg\u00e9 de recherche en acoustique musicale",
  "Charg\u00e9 de recherche et d\u00e9veloppement d\u00e9chets",
  "Charg\u00e9 de r\u00e9f\u00e9rencement web",
  "Charg\u00e9 des m\u00e9thodes outils et qualit\u00e9 en informatique",
  "Charg\u00e9 des relations publiques",
  "Charg\u00e9 de veille l\u00e9gislative et r\u00e9glementaire",
  "Charg\u00e9 d\'\u00e9tudes \u00e9conomiques",
  "Charg\u00e9 d\'\u00e9tudes en am\u00e9nagement",
  "Charg\u00e9 d\'\u00e9tudes en marketing",
  "Charg\u00e9 d\'\u00e9tudes en valorisation agricole des d\u00e9chets",
  "Charg\u00e9 d\'\u00e9tudes m\u00e9dia",
  "Charg\u00e9 d\'\u00e9tudes naturalistes",
  "Charg\u00e9 d\'\u00e9tudes ressources humaines",
  "Charpentier bois",
  "Charpentier m\u00e9tallique",
  "Chaudronnier",
  "Chauffeur de taxi",
  "Chef comptable",
  "Chef de chantier",
  "Chef de chantier en installations \u00e9lectriques",
  "Chef de cultures l\u00e9gumi\u00e8res",
  "Chef de fabrication des industries graphiques",
  "Chef de mission humanitaire",
  "Chef de produit marketing",
  "Chef de produit touristique",
  "Chef de projet biodiversit\u00e9",
  "Chef de projet d\u00e9mant\u00e8lement nucl\u00e9aire",
  "Chef de projet informatique",
  "Chef de projet multim\u00e9dia",
  "Chef de projet \u00e9olien",
  "Chef de projet sites et sols pollu\u00e9s",
  "Chef de projet territorial",
  "Chef de publicit\u00e9",
  "Chef de rayon",
  "Chef de station de traitement des eaux",
  "Chef des ventes",
  "Chef d\'exploitation d\'usine d\'incin\u00e9ration",
  "Chef monteur",
  "Chercheur en biologie",
  "Chercheur en biologie du sport",
  "Chercheur en chimie",
  "Chercheur en physique",
  "Chirurgien",
  "Chirurgien-dentiste",
  "\u00c9clairagiste",
  "Clerc d\'huissier",
  "Climatologue",
  "Coffreur",
  "Cogniticien",
  "Coiffeur",
  "Collaborateur de notaire",
  "Collecteur de fonds",
  "Com\u00e9dien",
  "Commer\u00e7ant en alimentation",
  "Commercial export",
  "Commissaire de police",
  "Commissaire-priseur",
  "Comptable",
  "Concepteur",
  "Concepteur de jeux vid\u00e9o",
  "Concepteur de niveaux de jeu web",
  "Concepteur multim\u00e9dia",
  "Conducteur",
  "Conducteur de bus ou d\'autocar",
  "Conducteur de ligne de production alimentaire",
  "Conducteur de machines agricoles",
  "Conducteur de machines \u00e0 imprimer",
  "Conducteur de machines \u00e0 papier",
  "Conducteur de m\u00e9tro",
  "Conducteur d\'engins de travaux publics",
  "Conducteur de scierie",
  "Conducteur de train / TGV",
  "Conducteur de travaux",
  "\u00c9conome de flux",
  "\u00c9conomiste de la construction",
  "Conseiller agricole",
  "Conseiller d\'\u00e9ducation",
  "Conseiller d\'insertion et de probation",
  "Conseiller d\'orientation-psychologue",
  "Conseiller en \u00e9conomie sociale et familiale",
  "Conseiller en environnement",
  "Conseiller en fusion-acquisition",
  "Conseiller en g\u00e9n\u00e9tique",
  "Conseiller en insertion sociale et professionnelle",
  "Conseiller en salle de remise en forme",
  "Conseiller en s\u00e9jours",
  "Conseiller en voyages",
  "Conseiller espace info-\u00e9nergie",
  "Conservateur du patrimoine",
  "Consignataire de navire",
  "Constructeur de routes",
  "Consultant",
  "Consultant en solutions int\u00e9gr\u00e9es",
  "Consultant en validation",
  "Consultant green IT",
  "Contr\u00f4leur",
  "Contr\u00f4leur",
  "Contr\u00f4leur de gestion",
  "Contr\u00f4leur de performances",
  "Contr\u00f4leur technique automobile",
  "Convoyeur de fonds",
  "Coordonnateur d\'\u00e9tudes cliniques",
  "Cordiste",
  "Cordonnier",
  "Correcteur",
  "Costumier",
  "Courtier",
  "Couvreur",
  "C\u00e9ramiste",
  "Credit manager",
  "Cuisinier",
  "Danseur",
  "D\u00e9clarant en douane",
  "D\u00e9colleteur",
  "D\u00e9corateur sc\u00e9nographe",
  "Designer",
  "Designer d\'interaction",
  "Designer sonore",
  "Dessinateur BTP",
  "Dessinateur de BD",
  "Dessinateur en construction m\u00e9canique",
  "Directeur",
  "Directeur artistique",
  "Directeur d\'agence bancaire",
  "Directeur de centre p\u00e9nitentiaire",
  "Directeur de cr\u00e9ation",
  "Directeur de la photographie",
  "Directeur de magasin \u00e0 grande surface",
  "Directeur de restaurant",
  "Directeur d\'h\u00f4pital",
  "Directeur d\'h\u00f4tel",
  "Directeur d\'office de tourisme",
  "\u00c9diteur",
  "Di\u00e9t\u00e9ticien",
  "D\u00e9m\u00e9nageur",
  "D\u00e9mographe",
  "Documentaliste",
  "Domoticien",
  "D\u00e9panneur en \u00e9lectrom\u00e9nager",
  "Dresseur d\'animaux",
  "\u00c9ducateur",
  "\u00c9ducateur",
  "\u00c9ducateur",
  "\u00c9ducateur de jeunes enfants",
  "\u00c9ducateur de la protection judiciaire de la jeunesse",
  "D\u00e9veloppeur \u00e9conomique",
  "D\u00e9veloppeur d\'applications mobiles",
  "D\u00e9veloppeur humanitaire",
  "D\u00e9veloppeur informatique",
  "Employ\u00e9 de pressing",
  "Employ\u00e9 de restaurant",
  "Encadreur",
  "Enqu\u00eateur priv\u00e9",
  "Enseignant",
  "Enseignant",
  "Enseignant d\'art",
  "Enseignant de la conduite automobile et de la s\u00e9curit\u00e9 routi\u00e8re",
  "Enseignant humanitaire",
  "Entra\u00eeneur",
  "Entra\u00eeneur de chevaux",
  "Ergonome",
  "Ergoth\u00e9rapeute",
  "Esth\u00e9ticien",
  "Ethnologue",
  "Expert automobile",
  "Expert bilan carbone",
  "Expert-comptable",
  "Expert en s\u00e9curit\u00e9 informatique",
  "Expert immobilier",
  "Fa\u00e7adier",
  "Facteur",
  "Facteur d\'instruments",
  "Fa\u00e7onnier des industries graphiques",
  "Femme de chambre",
  "Ferronnier d\'art",
  "Fiscaliste",
  "Fleuriste",
  "Formateur d\'adultes",
  "Formateur en informatique",
  "Formulateur",
  "Frigoriste",
  "Garde",
  "Garde \u00e0 cheval",
  "Gardien de la paix",
  "Gardien de police municipale",
  "Gar\u00e7on de caf\u00e9",
  "Gendarme",
  "Gestionnaire de contrats d\'assurance",
  "Gestionnaire de contrats informatiques",
  "Gestionnaire de donn\u00e9es cliniques",
  "Gestionnaire de patrimoine",
  "Gestionnaire de portefeuille",
  "G\u00e9n\u00e9ticien",
  "G\u00e9ochimiste",
  "G\u00e9ographe",
  "G\u00e9ologue",
  "G\u00e9ologue minier",
  "G\u00e9ologue mod\u00e9lisateur",
  "G\u00e9omaticien",
  "G\u00e9om\u00e8tre-topographe",
  "G\u00e9ophysicien",
  "G\u00e9otechnicien",
  "G\u00e9othermicien",
  "Gouvernante",
  "G\u00e9rant de restauration collective",
  "Graphiste",
  "Greffier",
  "Grutier",
  "Guichetier",
  "Guide conf\u00e9rencier des villes et pays d\'art et d\'histoire",
  "Guide de haute montagne",
  "Guide-interpr\u00e8te",
  "Halieute",
  "Histologiste",
  "Horloger",
  "Horticulteur",
  "Hot liner",
  "H\u00f4te d\'accueil",
  "H\u00f4tesse de l\'air",
  "Huissier de justice",
  "Hydraulicien",
  "Hydrog\u00e9ologue",
  "Hydrologue",
  "Iconographe",
  "Illustrateur",
  "Infirmier",
  "Infirmier humanitaire",
  "Informaticien",
  " ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur",
  "Ing\u00e9nieur analyste de l\'air",
  "Ing\u00e9nieur brevets",
  "Ing\u00e9nieur calcul",
  "Ing\u00e9nieur chimiste",
  "Ing\u00e9nieur chimiste en d\u00e9veloppement analytique",
  "Ing\u00e9nieur cloud computing",
  "Ing\u00e9nieur d\'application",
  "Ing\u00e9nieur de la police technique et scientifique",
  "Ing\u00e9nieur du BTP",
  "Ing\u00e9nieur du son",
  "Ing\u00e9nieur efficacit\u00e9 \u00e9nerg\u00e9tique du b\u00e2timent",
  "Ing\u00e9nieur en a\u00e9ronautique",
  "Ing\u00e9nieur en automatisme",
  "Ing\u00e9nieur en construction automobile",
  "Ing\u00e9nieur en construction navale",
  "Ing\u00e9nieur en g\u00e9nie climatique",
  "Ing\u00e9nieur en informatique",
  "Ing\u00e9nieur en \u00e9lectronique num\u00e9rique",
  "Ing\u00e9nieur en m\u00e9canique",
  "Ing\u00e9nieur en m\u00e9canique",
  "Ing\u00e9nieur en m\u00e9trologie",
  "Ing\u00e9nieur en \u00e9nergie solaire",
  "Ing\u00e9nieur en production et exp\u00e9rimentations v\u00e9g\u00e9tales",
  "Ing\u00e9nieur en R et D en \u00e9nergies renouvelables",
  "Ing\u00e9nieur environnement",
  "Ing\u00e9nieur environnement et risques industriels",
  "Ing\u00e9nieur essais",
  "Ing\u00e9nieur fluides, \u00e9nergies, r\u00e9seaux, environnement",
  "Ing\u00e9nieur forage",
  "Ing\u00e9nieur gaz",
  "Ing\u00e9nieur hydro\u00e9cologue",
  "Ing\u00e9nieur hydrog\u00e9omorphologue",
  "Ing\u00e9nieur maintenance a\u00e9ronautique",
  "Ing\u00e9nieur m\u00e9tallurgiste",
  "Ing\u00e9nieur m\u00e9thodes m\u00e9caniques",
  "Ing\u00e9nieur nucl\u00e9aire",
  "Ing\u00e9nieur plasturgiste",
  "Ing\u00e9nieur proc\u00e9d\u00e9s en chimie",
  "Ing\u00e9nieur process aval",
  "Ing\u00e9nieur production dans les biotechnologies",
  "Ing\u00e9nieur production en m\u00e9canique",
  "Ing\u00e9nieur radioprotection",
  "Ing\u00e9nieur recherche et d\u00e9veloppement en agroalimentaire",
  "Ing\u00e9nieur r\u00e9servoir",
  "Ing\u00e9nieur structures",
  "Ing\u00e9nieur syst\u00e8me",
  "Ing\u00e9nieur syst\u00e8mes embarqu\u00e9s",
  "Ing\u00e9nieur technico-commerciale en \u00e9lectronique",
  "Ing\u00e9nieur technico-commercial en chimie",
  "Ing\u00e9nieur textile",
  "Ing\u00e9nieur t\u00e9l\u00e9coms et r\u00e9seaux",
  "Ing\u00e9nieur \u00e9tudes et d\u00e9veloppement en logiciels de simulation",
  "Inspecteur",
  "Inspecteur de banque",
  "Inspecteur du permis de conduire et de la s\u00e9curit\u00e9 routi\u00e8re",
  "Installateur en t\u00e9l\u00e9coms",
  "Int\u00e9grateur web",
  "Journaliste",
  "Journaliste reporter d\'images",
  "Juge des enfants",
  "Juge d\'instance",
  "Juge d\'instruction",
  "Juriste d\'entreprise",
  "Juriste droit de l\'environnement",
  "Juriste en droit social",
  "Juriste en propri\u00e9t\u00e9 intellectuelle",
  "Lad-jockey, lad-driver",
  "\u00c9lagueur",
  "\u00c9lectricien",
  "\u00c9lectrom\u00e9canicien",
  "\u00c9lectronicien automobile",
  "\u00c9leveur",
  "Libraire",
  "Linguiste",
  "Logisticien",
  "Machiniste constructeur ou plateau",
  "Magasinier cariste",
  "Magistrat",
  "Manager de risques",
  "Mandataire judiciaire",
  "Manipulateur en \u00e9lectroradiologie m\u00e9dicale",
  "Ma\u00e7on",
  "Maquettiste",
  "Mara\u00eecher",
  "Mar\u00e9chal",
  "Marchandiseur",
  "Marin de commerce",
  "Marin p\u00eacheur",
  "Maroquinier",
  "Masseur-kin\u00e9sith\u00e9rapeute",
  "Matelot",
  "Ma\u00eetre-chien",
  "Ma\u00eetre  d\'h\u00f4tel",
  "Ma\u00eetre nageur sauveteur",
  "M\u00e9canicien",
  "M\u00e9canicien",
  "M\u00e9canicien bateaux",
  "M\u00e9canicien d\'entretien d\'avion",
  "M\u00e9canicien en mat\u00e9riel agricole",
  "M\u00e9canicien moto",
  "M\u00e9catronicien",
  "M\u00e9decin g\u00e9n\u00e9raliste",
  "M\u00e9decin humanitaire",
  "M\u00e9decin sp\u00e9cialiste",
  "M\u00e9diateur",
  "Menuisier",
  "Microbiologiste",
  "Microtechnicien",
  "Militaire du rang",
  "Militaire technicien",
  "Mixeur",
  "Modiste",
  "Mod\u00e9liste",
  "Moniteur",
  "Moniteur de ski",
  "Moniteur d\'\u00e9quitation",
  "Monteur",
  "Monteur en installations thermiques et climatiques",
  "Monteur en r\u00e9seaux de distribution \u00e9lectrique",
  "Mouleur",
  "M\u00e9t\u00e9orologiste",
  "Musicien",
  "Neurobiologiste",
  "Notaire",
  "Oc\u00e9anologue",
  "Oenologue",
  "Officier",
  "Officier de gendarmerie",
  "Officier de la marine marchande",
  "Officier de l\'arm\u00e9e de l\'air",
  "Officier de l\'arm\u00e9e de terre",
  "Officier de marine",
  "Officier de police",
  "Op\u00e9rateur de fabrication de produits alimentaires",
  "Op\u00e9rateur de raffinerie",
  "Op\u00e9rateur en traitement des mat\u00e9riaux",
  "Op\u00e9rateur pr\u00e9presse",
  "Op\u00e9rateur sur machine \u00e0 commande num\u00e9rique",
  "Opticien",
  "Optronicien",
  "Orf\u00e8vre",
  "Orthophoniste",
  "Orthoproth\u00e9siste",
  "Orthoptiste",
  "Ost\u00e9opathe",
  "Ouvrier",
  "Ouvrier agricole",
  "Ouvrier paysagiste",
  "Palefrenier",
  "Pal\u00e9ontologue",
  "Parfumeur",
  "Paysagiste",
  "P\u00e9diatre",
  "P\u00e9dicure-podologue",
  "P\u00e9dologue",
  "Peintre en b\u00e2timent",
  "Pharmacien",
  "Pharmacien dans l\'industrie",
  "Photographe",
  "Pilote de ligne",
  "Pilote de ligne automatis\u00e9e",
  "Plombier",
  "Pl\u00e2trier",
  "Podo-orth\u00e9siste",
  "Professeur dans l\'enseignement agricole",
  "Professeur d\'\u00e9ducation physique et sportive",
  "Professeur de coll\u00e8ge et de lyc\u00e9e",
  "Professeur de lyc\u00e9e professionnel ou technique",
  "Professeur de maths ou de physique-chimie",
  "Professeur de musique et de danse",
  "Professeur des \u00e9coles",
  "Professeur documentaliste",
  "Projectionniste",
  "Proth\u00e9siste dentaire",
  "Pr\u00e9parateur en pharmacie",
  "Psychanalyste",
  "Psychologue",
  "Psychomotricien",
  "P\u00e2tissier",
  "Pu\u00e9riculteur",
  "Qualiticien",
  "R\u00e9ceptionniste",
  "R\u00e9dacteur",
  "R\u00e9dacteur en chef",
  "R\u00e9dacteur on line",
  "Relieur",
  "Reporter-photographe",
  "Responsable assurance qualit\u00e9",
  "Responsable biom\u00e9trie",
  "Responsable de fabrication en agroalimentaire",
  "Responsable de formation",
  "Responsable de laboratoire de contr\u00f4le en biologie",
  "Responsable de la collecte des d\u00e9chets m\u00e9nagers",
  "Responsable de la promotion des ventes",
  "Responsable de la r\u00e9mun\u00e9ration",
  "Responsable de plate-forme biotechnologique",
  "Responsable de projets culturels",
  "Responsable de r\u00e9seau d\'assainissement",
  "Responsable de r\u00e9seau eau potable",
  "Responsable de scierie",
  "Responsable de site de traitement des d\u00e9chets",
  "Responsable des ressources humaines",
  "Responsable d\'ordonnancement",
  "Responsable du back-office",
  "Responsable du recrutement",
  "Responsable du service apr\u00e8s-vente",
  "Responsable du soutien logistique int\u00e9gr\u00e9",
  "Responsable micro",
  "Responsable qualit\u00e9 en agroalimentaire",
  "Restaurateur d\'oeuvres d\'art",
  "R\u00e9gisseur cin\u00e9ma",
  "R\u00e9gisseur de spectacles",
  "R\u00e9gleur",
  "Rudologue",
  "Sage-femme",
  "Salesman",
  "Sapeur",
  "Sc\u00e9nariste",
  "Scripte",
  "Secr\u00e9taire",
  "Secr\u00e9taire administratif",
  "Secr\u00e9taire d\'\u00e9dition",
  "Secr\u00e9taire de r\u00e9daction",
  "Secr\u00e9taire des Affaires \u00e9trang\u00e8res",
  "Secr\u00e9taire juridique",
  "Secr\u00e9taire m\u00e9dical",
  "Sellier",
  "Serrurier",
  "Sociologue",
  "Soigneur",
  "Solier-moquettiste",
  "Sommelier",
  "Soudeur",
  "Souffleur de verre",
  "Souscripteur",
  "Sous-officier de l\'arm\u00e9e de l\'air",
  "Sous-officier de l\'arm\u00e9e de terre",
  "Sp\u00e9cialiste des affaires r\u00e9glementaires en chimie",
  "Sportif de haut niveau",
  "S\u00e9rigraphe",
  "Staffeur-ornemaniste",
  "Statisticien",
  "Styliste",
  "Substitut du procureur",
  "Surveillant de centre p\u00e9nitentiaire",
  "Syndic de copropri\u00e9t\u00e9",
  "Tailleur",
  "Tailleur de pierre",
  "\u00c9talagiste",
  "\u00c9tanch\u00e9iste",
  "Tapissier d\'ameublement",
  "Technicien",
  "Technicien",
  "Technicien",
  "Technicien",
  "Technicien",
  "Technicien automobile",
  "Technicien biologiste",
  "Technicien chimiste",
  "Technicien c\u00e9ramiste",
  "Technicien d\'analyses biom\u00e9dicales",
  "Technicien de fabrication de mobilier et de menuiserie",
  "Technicien de forge",
  "Technicien de l\'intervention sociale et familiale",
  "Technicien de maintenance en g\u00e9nie climatique",
  "Technicien de maintenance en informatique",
  "Technicien de maintenance industrielle",
  "Technicien de police technique et scientifique",
  "Technicien des industries du verre",
  "Technicien d\'essais",
  "Technicien d\'exploitation de l\'eau",
  "Technicien d\'exploitation du r\u00e9seau gaz",
  "Technicien d\'intervention client\u00e8le gaz",
  "Technicien en automatismes",
  "Technicien en engins de travaux publics",
  "Technicien en lignes haute tension",
  "Technicien en m\u00e9trologie",
  "Technicien en optique de pr\u00e9cision",
  "Technicien en traitement des d\u00e9chets",
  "Technicien nucl\u00e9aire",
  "Technicien paysagiste",
  "Technicien plasturgiste",
  "Technicien t\u00e9l\u00e9coms et r\u00e9seaux",
  "Technico-commercial en agroalimentaire",
  "Techniverrier",
  "Teinturier",
  "Testeur en informatique",
  "T\u00e9l\u00e9vendeur",
  "Toiletteur d\'animaux",
  "Tonnelier",
  "Trader",
  "Traducteur-interpr\u00e8te",
  "Urbaniste",
  "Veilleur strat\u00e9gique",
  "Vendeur-conseil en mat\u00e9riel agricole",
  "Vendeur en animalerie",
  "Vendeur en fournitures automobiles",
  "Vendeur en magasin",
  "Vendeur en micro-informatique et multim\u00e9dia",
  "Verrier au chalumeau",
  "Visiteur",
  "Viticulteur",
  "Vitrailliste",
  "Volcanologue",
  "V\u00e9t\u00e9rinaire",
  "Webdesigner",
  "Webmestre",
  "Zoologiste"
)

#' Job provider for France
#'
#' @inherit JobProvider description details return
#' @family fr
#' @family FR
#' @export
#' @examples
#' x <- JobProvider_fr_FR$new()
#' x$render()
JobProvider_fr_FR <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_fr_FR",
  private = list(
    locale_ = "fr_FR",
    formats = job_formats_fr_fr
  )
)
